#include <AcceleroMMA7361.h>
#include <Practicum.h>
#define PIN_X PIN_PC0
#define PIN_Y PIN_PC2
#define PIN_Z PIN_PC4


AcceleroMMA7361 accelero;

extern "C" {
#include "usbdrv.h"
}

#define RQ_SET_LED    0
#define RQ_GET_SWITCH_RIGHT 1
#define RQ_GET_X  2
#define RQ_GET_SWITCH_LEFT 3

//////////////////////////////////////////////////////////////////////
usbMsgLen_t usbFunctionSetup(uint8_t data[8])
{
  usbRequest_t *rq = (usbRequest_t*)data;
  static uint8_t switch_state;  /* must stay when usbFunctionSetup returns */
  static uint8_t switch_state_LEFT;
  
  if (rq->bRequest == RQ_SET_LED)
  {
    uint8_t led_val = rq->wValue.bytes[0];
    uint8_t led_no  = rq->wIndex.bytes[0];
    
    digitalWrite(PIN_PC3, 1);
    
    return 0;  // return no data back to host
  }

  else if (rq->bRequest == RQ_GET_SWITCH_RIGHT)
  {
    if (digitalRead(PIN_PC5) == LOW) /* switch is pressed */ 
      switch_state = 1;
    else
      switch_state = 0;

    /* point usbMsgPtr to the data to be returned to host */
    usbMsgPtr = (uint8_t*) &switch_state;

    /* return the number of bytes of data to be returned to host */
    return sizeof(switch_state);
  }
    else if (rq->bRequest == RQ_GET_SWITCH_LEFT)
  {
    if (digitalRead(PIN_PC1) == LOW) /* switch is pressed */ 
      switch_state_LEFT = 1;
    else
      switch_state_LEFT = 0;

    /* point usbMsgPtr to the data to be returned to host */
    usbMsgPtr = (uint8_t*) &switch_state_LEFT;

    /* return the number of bytes of data to be returned to host */
    return sizeof(switch_state_LEFT);
  }

  else if (rq->bRequest == RQ_GET_X)
  {
    uint16_t light_val = accelero.getXAccel();
    static int8_t ret_val[2];
    
    ret_val[0] = light_val & 0x00FF;
    ret_val[1] = light_val >> 8;
    
    usbMsgPtr =  (uint8_t*) &ret_val;
    
    return sizeof(ret_val);
  }

  return 0;   /* nothing to do; return no data back to host */
}

//////////////////////////////////////////////////////////////////////
void setup()
{
    pinMode(PIN_X, INPUT); // X
    pinMode(PIN_PC1, INPUT_PULLUP); //SWITCH LEFT 
    pinMode(PIN_Y, INPUT); // Y
    pinMode(PIN_PC3, OUTPUT); // LED
    pinMode(PIN_Z, INPUT); // Z
    pinMode(PIN_PC5, INPUT_PULLUP); //SWITCH RIGHT
    pinMode(PIN_PD3, OUTPUT);
    
    accelero.begin(13, 12, 11, 10, PIN_X, PIN_Y, PIN_Z);
    accelero.setARefVoltage(5); //sets the AREF voltage to 3.3V
    accelero.setSensitivity(LOW); //sets the sensitivity to +/-6G
    accelero.calibrate();

    usbInit();

    /* enforce re-enumeration of USB devices */
    usbDeviceDisconnect();
    delay(300);
    usbDeviceConnect();
}

//////////////////////////////////////////////////////////////////////
void loop()
{
  usbPoll();
}
